API Reference
=============

Detailed documentation for the classes and functions in ``scikit-clarans``.

CLARANS
--------------

The core class you will interact with.

.. autoclass:: clarans.CLARANS
   :members:
   :inherited-members:
   :show-inheritance:
.. autoclass:: clarans.FastCLARANS
   :members:
   :inherited-members:
   :show-inheritance:

Helper Modules
--------------

Internal modules for initialization and utilities.

.. automodule:: clarans.initialization
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: clarans.utils
   :members:
   :undoc-members:
   :show-inheritance:
